@@ -1,27 +1,27 @@
 """Manage a directory in a *parent* filesystem.
 """
 
-from __future__ import print_function
-from __future__ import unicode_literals
+from __future__ import print_function, unicode_literals
 
 import typing
 
 import six
 
-from .wrapfs import WrapFS
 from .path import abspath, join, normpath, relpath
+from .wrapfs import WrapFS
 
 if typing.TYPE_CHECKING:
-    from .base import FS  # noqa: F401
     from typing import Text, Tuple
 
+    from .base import FS  # noqa: F401
+
 
 _F = typing.TypeVar("_F", bound="FS", covariant=True)
 
 
 @six.python_2_unicode_compatible
 class SubFS(WrapFS[_F], typing.Generic[_F]):
-    """A sub-directory on another filesystem.
+    """A sub-directory on a parent filesystem.
 
     A SubFS is a filesystem object that maps to a sub-directory of
     another filesystem. This is the object that is returned by
